diff --git a/GMW/GMW/Type/Cartellino.cs b/GMW/GMW/Type/Cartellino.cs
index c580e4c7..54adee89 100644
--- a/GMW/GMW/Type/Cartellino.cs
+++ b/GMW/GMW/Type/Cartellino.cs
@@ -16,33 +16,33 @@ namespace GMW.Type
}
public Cartellino(DS_Applicazione.ElencoCartelliniRow riga)
{
- UDC = riga.UDC;
- CodCS = riga.CodCS;
- CodCliente = riga.CodCliente;
- RagSociale = riga.RagSociale;
- Particolare = riga.Particolare;
+ UDC = riga.UDC;
+ CodCS = riga.CodCS;
+ CodCliente = riga.CodCliente;
+ RagSociale = riga.RagSociale;
+ Particolare = riga.Particolare;
DescParticolare = riga.DescParticolare;
- DisegnoGrezzo = riga.DisegnoGrezzo;
- Esponente = riga.Esponente;
- CodImpianto = riga.CodImpianto;
- DescImpianto = riga.DescImpianto;
- CodCliente = riga.CodCliente;
- CodStampo = riga.CodStampo;
- Figura = riga.Figura;
- DataFus = riga.DataFus;
- TurnoFus = riga.TurnoFus;
- CodImballo = riga.CodImballo;
- CodSoggetto = riga.CodSoggetto;
+ DisegnoGrezzo = riga.DisegnoGrezzo;
+ Esponente = riga.Esponente;
+ CodImpianto = riga.CodImpianto;
+ DescImpianto = riga.DescImpianto;
+ CodCliente = riga.CodCliente;
+ CodStampo = riga.CodStampo;
+ Figura = riga.Figura;
+ DataFus = riga.DataFus;
+ TurnoFus = riga.TurnoFus;
+ CodImballo = riga.CodImballo;
+ CodSoggetto = riga.CodSoggetto;
NomeSoggetto = riga.CodSoggetto; // !!! correggere
- NumCont = riga.NumCont;
- Tara = riga.Tara;
- Qta = riga.Qta;
- CodStato = riga.CodStato;
- IdxPosizione = riga.IdxPosizione;
- PesoTot = riga.PesoTot;
- PesoCad = riga.PesoCad;
- CreateDate = riga.CreateDate;
- ModDate = riga.ModDate;
+ NumCont = riga.NumCont;
+ Tara = riga.Tara;
+ Quantita = riga.Qta;
+ CodStato = riga.CodStato;
+ IdxPosizione = riga.IdxPosizione;
+ PesoTot = riga.PesoTot;
+ PesoCad = riga.PesoCad;
+ CreateDate = riga.CreateDate;
+ ModDate = riga.ModDate;
}
///
@@ -124,7 +124,7 @@ namespace GMW.Type
///
/// Quantità associata all'UDC
///
- public decimal Qta { get; set; }
+ public decimal Quantita { get; set; }
///
/// Codice Stato pezzo (sabbiato, smaterozzato, ...)
///
@@ -175,7 +175,7 @@ namespace GMW.Type
NomeSoggetto = riga.CodSoggetto; // !!! correggere
NumCont = riga.NumCont;
Tara = riga.Tara;
- Qta = riga.Qta;
+ Quantita = riga.Qta;
CodStato = riga.CodStato;
IdxPosizione = riga.IdxPosizione;
PesoTot = riga.PesoTot;
diff --git a/GMW/GMW/WS/bilance.asmx.cs b/GMW/GMW/WS/bilance.asmx.cs
index 2ccf56ca..7675d893 100644
--- a/GMW/GMW/WS/bilance.asmx.cs
+++ b/GMW/GMW/WS/bilance.asmx.cs
@@ -289,13 +289,13 @@ namespace GMW.WS
/// codice dell'UDC parent (UDC della tara)
/// peso in kg (0 se non noto) da associare all'UDC come tara del contenitore
/// tipo di dichiarazione (vedere relativa anagrafica consentita, es U=uomo, M=macchina...)
- /// numero pezzi associati all'UDC
+ /// numero pezzi associati all'UDC
/// Peso totale rilevato
/// Peso unitario rilevato
/// Codice dello stato del pezzo (da anagrafica: sabbiato, ...)
/// UDC del nuovo cartellino
[WebMethod(Description = "Fornisce un nuovo codice UDC tipo completo (con pezzi) a partire dalla richiesta e salva i dati")]
- public string UdcCall_GetNew_Pesa(string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int qta, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
+ public string UdcCall_GetNew_Pesa(string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int Quantita, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
{
// ricavo cod company...
string CodCS = "ND";
@@ -309,8 +309,8 @@ namespace GMW.WS
CodCS = memLayer.ML.confReadString("CodCS");
}
int IdxPosizione = 20; // hard coded: è la postazione POST fusione di ambivere!!!
- // faccio update!
- DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_insNewFull(CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_PESA", qta, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_PESA" è "hard coded" nel db... !!!
+ // creo nuovo cartellino!
+ DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_insNewFull(CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_PESA", Quantita, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_PESA" è "hard coded" nel db... !!!
// leggo la riga
try
{
@@ -323,6 +323,72 @@ namespace GMW.WS
return answ;
}
+ ///
+ /// Modifica (se possibile poiché sbloccato) un cartellino esistente dato il suo UDC e salva i dati, restituendo conferma avvenuta modifica (true/false)
+ ///
+ /// codice UDC del cartellino che si vuole modificare
+ /// codice anagrafico della bilanca che effettua la richiesta (codice della pesa)
+ /// codice anagrafico del cliente
+ /// codice del particolare (articolo) - da anagrafica!
+ /// Codice dell'impianto
+ /// Codice dello stampo
+ /// codice dell'esponente dello stampo
+ /// Codice figura
+ /// Data di rif per la dichiarazione
+ /// Turno di rif per la dichiarazione
+ /// codice dell'imballo (tipo cassone) - string LIBERO (non facciamo controlli in input)
+ /// codice dell'operatore
+ /// codice dell'UDC parent (UDC della tara)
+ /// peso in kg (0 se non noto) da associare all'UDC come tara del contenitore
+ /// tipo di dichiarazione (vedere relativa anagrafica consentita, es U=uomo, M=macchina...)
+ /// numero pezzi associati all'UDC
+ /// Peso totale rilevato
+ /// Peso unitario rilevato
+ /// Codice dello stato del pezzo (da anagrafica: sabbiato, ...)
+ /// UDC del nuovo cartellino
+ [WebMethod(Description = "Modifica (se possibile poiché sbloccato) un cartellino esistente dato il suo UDC e salva i dati, restituendo conferma avvenuta modifica (true/false)")]
+ public bool UdcCall_ModificaCartellino(string UDC_edit, string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int Quantita, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
+ {
+ // ricavo cod company...
+ string CodCS = "ND";
+ bool answ = false;
+ // controllo se si possa aggiornare...
+ GMW.Type.Cartellino currCart = new GMW.Type.Cartellino(DataProxy.obj.taCartellini.stp_getByUdc(UDC_edit)[0]);
+ int maxTimeMod = memLayer.ML.confReadInt("MinutiFinestraEditUDC");
+ double elapsedTime = DateTime.Now.Subtract(currCart.ModDate).TotalMinutes;
+ if (DateTime.Now.Subtract(currCart.ModDate).TotalMinutes > maxTimeMod)
+ {
+ logger.lg.scriviLog(string.Format("NEGATA Richiesta modifica UDC codice {0} fuori tempo massimo: finestra ammessa {1} min, sono passati {2} min da creazione/sblocco", UDC_edit, maxTimeMod, elapsedTime), tipoLog.WARNING);
+ }
+ else
+ {
+ logger.lg.scriviLog(string.Format("Concessa Richiesta modifica UDC codice {0} fuori tempo massimo: finestra ammessa {1} min, sono passati {2} min da creazione/sblocco", UDC_edit, maxTimeMod, elapsedTime), tipoLog.INFO);
+ try
+ {
+ CodCS = DataProxy.obj.taAnagBil.stp_getByCodBilancia(CodBilancia)[0].CodCS;
+ }
+ catch
+ {
+ CodCS = memLayer.ML.confReadString("CodCS");
+ }
+ int IdxPosizione = 20; // hard coded: è la postazione POST fusione di ambivere!!!
+ // faccio update!
+ DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_updateUDC(UDC_edit, CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_MOD", Quantita, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_MOD" è "hard coded" nel db... !!!
+ // leggo la riga
+ try
+ {
+ if (UDC_edit == tabUdc[0].UDC)
+ {
+ answ = true;
+ }
+ }
+ catch
+ { }
+ }
+ return answ;
+ }
+
+
///
/// Annulla un dato UDC (se permesso)
///
diff --git a/GMW/GMW/Web.config b/GMW/GMW/Web.config
index 4c8950d7..dc40fc24 100644
--- a/GMW/GMW/Web.config
+++ b/GMW/GMW/Web.config
@@ -85,6 +85,7 @@
+
diff --git a/GMW/GMW/bin/GMW.dll b/GMW/GMW/bin/GMW.dll
index 9edce19c..e5075e15 100644
Binary files a/GMW/GMW/bin/GMW.dll and b/GMW/GMW/bin/GMW.dll differ
diff --git a/GMW/GMW/bin/GMW_data.dll b/GMW/GMW/bin/GMW_data.dll
index abe4b49d..188efcb9 100644
Binary files a/GMW/GMW/bin/GMW_data.dll and b/GMW/GMW/bin/GMW_data.dll differ
diff --git a/GMW/GMW/bin/SteamWare.dll b/GMW/GMW/bin/SteamWare.dll
index 2a90c2c0..6980cf83 100644
Binary files a/GMW/GMW/bin/SteamWare.dll and b/GMW/GMW/bin/SteamWare.dll differ
diff --git a/GMW/GMW/mazzAppSettings.config b/GMW/GMW/mazzAppSettings.config
index 62cc312a..c320072d 100644
--- a/GMW/GMW/mazzAppSettings.config
+++ b/GMW/GMW/mazzAppSettings.config
@@ -3,5 +3,8 @@
+
+
+
\ No newline at end of file
diff --git a/GMW/GMW/obj/Debug/GMW.dll b/GMW/GMW/obj/Debug/GMW.dll
index 9edce19c..326a25de 100644
Binary files a/GMW/GMW/obj/Debug/GMW.dll and b/GMW/GMW/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache
index 19d614a2..f6de817f 100644
Binary files a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW/obj/Release/GMW.dll b/GMW/GMW/obj/Release/GMW.dll
index 147d8bd8..e5075e15 100644
Binary files a/GMW/GMW/obj/Release/GMW.dll and b/GMW/GMW/obj/Release/GMW.dll differ
diff --git a/GMW/GMW/obj/Release/ResolveAssemblyReference.cache b/GMW/GMW/obj/Release/ResolveAssemblyReference.cache
index 7f8e5731..b44c8dc2 100644
Binary files a/GMW/GMW/obj/Release/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Release/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_data/DS_Applicazione.Designer.cs b/GMW/GMW_data/DS_Applicazione.Designer.cs
index 61560932..abe15dde 100644
--- a/GMW/GMW_data/DS_Applicazione.Designer.cs
+++ b/GMW/GMW_data/DS_Applicazione.Designer.cs
@@ -13331,7 +13331,7 @@ SELECT UDC, CodCS, CodCliente, RagSociale, Particolare, DescParticolare, Disegno
[global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
private void InitCommandCollection() {
- this._commandCollection = new global::System.Data.SqlClient.SqlCommand[6];
+ this._commandCollection = new global::System.Data.SqlClient.SqlCommand[7];
this._commandCollection[0] = new global::System.Data.SqlClient.SqlCommand();
this._commandCollection[0].Connection = this.Connection;
this._commandCollection[0].CommandText = @"SELECT UDC, CodCS, CodCliente, RagSociale, Particolare, DescParticolare, DisegnoGrezzo, Esponente, CodImpianto, DescImpianto, CodStampo, Figura, DataFus, TurnoFus, CodImballo, CodSoggetto, NumCont, Tara, Qta, CodStato, IdxPosizione, PesoTot, PesoCad, CreateDate, ModDate FROM dbo.ElencoCartellini";
@@ -13396,6 +13396,34 @@ SELECT UDC, CodCS, CodCliente, RagSociale, Particolare, DescParticolare, Disegno
this._commandCollection[5].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@RETURN_VALUE", global::System.Data.SqlDbType.Int, 4, global::System.Data.ParameterDirection.ReturnValue, 10, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
this._commandCollection[5].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@UDC", global::System.Data.SqlDbType.VarChar, 20, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
this._commandCollection[5].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodSoggetto", global::System.Data.SqlDbType.VarChar, 16, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6] = new global::System.Data.SqlClient.SqlCommand();
+ this._commandCollection[6].Connection = this.Connection;
+ this._commandCollection[6].CommandText = "dbo.stp_UDC_update";
+ this._commandCollection[6].CommandType = global::System.Data.CommandType.StoredProcedure;
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@RETURN_VALUE", global::System.Data.SqlDbType.Int, 4, global::System.Data.ParameterDirection.ReturnValue, 10, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@UDC_edit", global::System.Data.SqlDbType.VarChar, 20, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodCS", global::System.Data.SqlDbType.VarChar, 2, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Flusso", global::System.Data.SqlDbType.VarChar, 2, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Anno", global::System.Data.SqlDbType.VarChar, 2, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodCliente", global::System.Data.SqlDbType.VarChar, 6, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Particolare", global::System.Data.SqlDbType.VarChar, 15, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodImpianto", global::System.Data.SqlDbType.VarChar, 50, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodStampo", global::System.Data.SqlDbType.VarChar, 8, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Esponente", global::System.Data.SqlDbType.VarChar, 6, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Figura", global::System.Data.SqlDbType.VarChar, 4, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@DataFus", global::System.Data.SqlDbType.DateTime, 8, global::System.Data.ParameterDirection.Input, 23, 3, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@TurnoFus", global::System.Data.SqlDbType.Int, 4, global::System.Data.ParameterDirection.Input, 10, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodImballo", global::System.Data.SqlDbType.VarChar, 15, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodSoggetto", global::System.Data.SqlDbType.VarChar, 16, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Tara", global::System.Data.SqlDbType.Float, 8, global::System.Data.ParameterDirection.Input, 53, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@IdxPosizione", global::System.Data.SqlDbType.Int, 4, global::System.Data.ParameterDirection.Input, 10, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodTipoDichiaraz", global::System.Data.SqlDbType.Char, 1, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodEvento", global::System.Data.SqlDbType.VarChar, 10, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@Qta", global::System.Data.SqlDbType.Decimal, 9, global::System.Data.ParameterDirection.Input, 10, 2, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@PesoTot", global::System.Data.SqlDbType.Float, 8, global::System.Data.ParameterDirection.Input, 53, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@PesoCad", global::System.Data.SqlDbType.Float, 8, global::System.Data.ParameterDirection.Input, 53, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@CodStato", global::System.Data.SqlDbType.VarChar, 50, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
+ this._commandCollection[6].Parameters.Add(new global::System.Data.SqlClient.SqlParameter("@UDC_parent", global::System.Data.SqlDbType.VarChar, 20, global::System.Data.ParameterDirection.Input, 0, 0, null, global::System.Data.DataRowVersion.Current, false, null, "", "", ""));
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
@@ -13658,6 +13686,177 @@ SELECT UDC, CodCS, CodCliente, RagSociale, Particolare, DescParticolare, Disegno
return dataTable;
}
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
+ [global::System.ComponentModel.Design.HelpKeywordAttribute("vs.data.TableAdapter")]
+ [global::System.ComponentModel.DataObjectMethodAttribute(global::System.ComponentModel.DataObjectMethodType.Select, false)]
+ public virtual DS_Applicazione.ElencoCartelliniDataTable stp_updateUDC(
+ string UDC_edit,
+ string CodCS,
+ string Flusso,
+ string Anno,
+ string CodCliente,
+ string Particolare,
+ string CodImpianto,
+ string CodStampo,
+ string Esponente,
+ string Figura,
+ global::System.Nullable DataFus,
+ global::System.Nullable TurnoFus,
+ string CodImballo,
+ string CodSoggetto,
+ global::System.Nullable Tara,
+ global::System.Nullable IdxPosizione,
+ string CodTipoDichiaraz,
+ string CodEvento,
+ global::System.Nullable Qta,
+ global::System.Nullable PesoTot,
+ global::System.Nullable PesoCad,
+ string CodStato,
+ string UDC_parent) {
+ this.Adapter.SelectCommand = this.CommandCollection[6];
+ if ((UDC_edit == null)) {
+ this.Adapter.SelectCommand.Parameters[1].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[1].Value = ((string)(UDC_edit));
+ }
+ if ((CodCS == null)) {
+ this.Adapter.SelectCommand.Parameters[2].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[2].Value = ((string)(CodCS));
+ }
+ if ((Flusso == null)) {
+ this.Adapter.SelectCommand.Parameters[3].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[3].Value = ((string)(Flusso));
+ }
+ if ((Anno == null)) {
+ this.Adapter.SelectCommand.Parameters[4].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[4].Value = ((string)(Anno));
+ }
+ if ((CodCliente == null)) {
+ this.Adapter.SelectCommand.Parameters[5].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[5].Value = ((string)(CodCliente));
+ }
+ if ((Particolare == null)) {
+ this.Adapter.SelectCommand.Parameters[6].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[6].Value = ((string)(Particolare));
+ }
+ if ((CodImpianto == null)) {
+ this.Adapter.SelectCommand.Parameters[7].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[7].Value = ((string)(CodImpianto));
+ }
+ if ((CodStampo == null)) {
+ this.Adapter.SelectCommand.Parameters[8].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[8].Value = ((string)(CodStampo));
+ }
+ if ((Esponente == null)) {
+ this.Adapter.SelectCommand.Parameters[9].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[9].Value = ((string)(Esponente));
+ }
+ if ((Figura == null)) {
+ this.Adapter.SelectCommand.Parameters[10].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[10].Value = ((string)(Figura));
+ }
+ if ((DataFus.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[11].Value = ((System.DateTime)(DataFus.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[11].Value = global::System.DBNull.Value;
+ }
+ if ((TurnoFus.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[12].Value = ((int)(TurnoFus.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[12].Value = global::System.DBNull.Value;
+ }
+ if ((CodImballo == null)) {
+ this.Adapter.SelectCommand.Parameters[13].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[13].Value = ((string)(CodImballo));
+ }
+ if ((CodSoggetto == null)) {
+ this.Adapter.SelectCommand.Parameters[14].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[14].Value = ((string)(CodSoggetto));
+ }
+ if ((Tara.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[15].Value = ((double)(Tara.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[15].Value = global::System.DBNull.Value;
+ }
+ if ((IdxPosizione.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[16].Value = ((int)(IdxPosizione.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[16].Value = global::System.DBNull.Value;
+ }
+ if ((CodTipoDichiaraz == null)) {
+ this.Adapter.SelectCommand.Parameters[17].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[17].Value = ((string)(CodTipoDichiaraz));
+ }
+ if ((CodEvento == null)) {
+ this.Adapter.SelectCommand.Parameters[18].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[18].Value = ((string)(CodEvento));
+ }
+ if ((Qta.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[19].Value = ((decimal)(Qta.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[19].Value = global::System.DBNull.Value;
+ }
+ if ((PesoTot.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[20].Value = ((double)(PesoTot.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[20].Value = global::System.DBNull.Value;
+ }
+ if ((PesoCad.HasValue == true)) {
+ this.Adapter.SelectCommand.Parameters[21].Value = ((double)(PesoCad.Value));
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[21].Value = global::System.DBNull.Value;
+ }
+ if ((CodStato == null)) {
+ this.Adapter.SelectCommand.Parameters[22].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[22].Value = ((string)(CodStato));
+ }
+ if ((UDC_parent == null)) {
+ this.Adapter.SelectCommand.Parameters[23].Value = global::System.DBNull.Value;
+ }
+ else {
+ this.Adapter.SelectCommand.Parameters[23].Value = ((string)(UDC_parent));
+ }
+ DS_Applicazione.ElencoCartelliniDataTable dataTable = new DS_Applicazione.ElencoCartelliniDataTable();
+ this.Adapter.Fill(dataTable);
+ return dataTable;
+ }
+
[global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
[global::System.ComponentModel.Design.HelpKeywordAttribute("vs.data.TableAdapter")]
public virtual int Update(DS_Applicazione.ElencoCartelliniDataTable dataTable) {
diff --git a/GMW/GMW_data/DS_Applicazione.xsd b/GMW/GMW_data/DS_Applicazione.xsd
index b35a8f9f..8039ad54 100644
--- a/GMW/GMW_data/DS_Applicazione.xsd
+++ b/GMW/GMW_data/DS_Applicazione.xsd
@@ -1066,6 +1066,39 @@ SELECT UDC, CodCS, CodCliente, RagSociale, Particolare, DescParticolare, Disegno
+
+
+
+ dbo.stp_UDC_update
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -1331,8 +1364,8 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
-
+
+
@@ -1345,14 +1378,14 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
@@ -1365,14 +1398,14 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
@@ -1385,28 +1418,28 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
-
+
-
+
@@ -1419,37 +1452,37 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
-
-
-
+
+
+
-
+
-
+
@@ -1462,82 +1495,82 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
-
-
+
+
+
-
+
-
+
-
+
-
+
-
+
-
-
-
-
+
+
+
+
-
+
-
+
-
+
-
+
@@ -1550,14 +1583,14 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
@@ -1570,35 +1603,35 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
-
+
-
+
-
+
@@ -1611,331 +1644,6 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -1943,49 +1651,374 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
+
-
+
-
+
-
+
@@ -1995,17 +2028,17 @@ SELECT CodCliente, RagSociale FROM RilPro.AnagClienti WHERE (CodCliente = @CodCl
-
+
-
+
-
+
diff --git a/GMW/GMW_data/DS_Applicazione.xss b/GMW/GMW_data/DS_Applicazione.xss
index 43b14076..6aa9cccd 100644
--- a/GMW/GMW_data/DS_Applicazione.xss
+++ b/GMW/GMW_data/DS_Applicazione.xss
@@ -4,7 +4,7 @@
Changes to this file may cause incorrect behavior and will be lost if
the code is regenerated.
-->
-
+
@@ -16,11 +16,11 @@
-
+
-
-
-
+
+
+
@@ -103,7 +103,7 @@
-
+
1181
diff --git a/GMW/GMW_data/bin/Debug/GMW_data.dll b/GMW/GMW_data/bin/Debug/GMW_data.dll
index abe4b49d..981eeabe 100644
Binary files a/GMW/GMW_data/bin/Debug/GMW_data.dll and b/GMW/GMW_data/bin/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/bin/Release/GMW_data.dll b/GMW/GMW_data/bin/Release/GMW_data.dll
index c88dbea2..188efcb9 100644
Binary files a/GMW/GMW_data/bin/Release/GMW_data.dll and b/GMW/GMW_data/bin/Release/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/GMW_data.dll b/GMW/GMW_data/obj/Debug/GMW_data.dll
index abe4b49d..981eeabe 100644
Binary files a/GMW/GMW_data/obj/Debug/GMW_data.dll and b/GMW/GMW_data/obj/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/TempPE/DS_Applicazione.Designer.cs.dll b/GMW/GMW_data/obj/Debug/TempPE/DS_Applicazione.Designer.cs.dll
index 5e73ecaf..da18ee3d 100644
Binary files a/GMW/GMW_data/obj/Debug/TempPE/DS_Applicazione.Designer.cs.dll and b/GMW/GMW_data/obj/Debug/TempPE/DS_Applicazione.Designer.cs.dll differ
diff --git a/GMW/GMW_data/obj/Release/GMW_data.dll b/GMW/GMW_data/obj/Release/GMW_data.dll
index c88dbea2..188efcb9 100644
Binary files a/GMW/GMW_data/obj/Release/GMW_data.dll and b/GMW/GMW_data/obj/Release/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Release/TempPE/DS_Applicazione.Designer.cs.dll b/GMW/GMW_data/obj/Release/TempPE/DS_Applicazione.Designer.cs.dll
index 6355c002..f4f06220 100644
Binary files a/GMW/GMW_data/obj/Release/TempPE/DS_Applicazione.Designer.cs.dll and b/GMW/GMW_data/obj/Release/TempPE/DS_Applicazione.Designer.cs.dll differ
diff --git a/GMW/GMW_deploy/Release/GMW.csproj b/GMW/GMW_deploy/Release/GMW.csproj
index c8f31803..0f50dd20 100644
--- a/GMW/GMW_deploy/Release/GMW.csproj
+++ b/GMW/GMW_deploy/Release/GMW.csproj
@@ -77,10 +77,11 @@
+
-
+
diff --git a/GMW/GMW_deploy/Release/bin/GMW.dll b/GMW/GMW_deploy/Release/bin/GMW.dll
index 147d8bd8..e5075e15 100644
Binary files a/GMW/GMW_deploy/Release/bin/GMW.dll and b/GMW/GMW_deploy/Release/bin/GMW.dll differ
diff --git a/GMW/GMW_deploy/Release/bin/GMW_data.dll b/GMW/GMW_deploy/Release/bin/GMW_data.dll
index c88dbea2..188efcb9 100644
Binary files a/GMW/GMW_deploy/Release/bin/GMW_data.dll and b/GMW/GMW_deploy/Release/bin/GMW_data.dll differ
diff --git a/GMW/GMW_deploy/Release/mazzAppSettings.config b/GMW/GMW_deploy/Release/mazzAppSettings.config
index 62cc312a..c320072d 100644
--- a/GMW/GMW_deploy/Release/mazzAppSettings.config
+++ b/GMW/GMW_deploy/Release/mazzAppSettings.config
@@ -3,5 +3,8 @@
+
+
+
\ No newline at end of file
diff --git a/GMW/GMW_deploy/Release/obj/Debug/GMW.dll b/GMW/GMW_deploy/Release/obj/Debug/GMW.dll
index 0356dddd..326a25de 100644
Binary files a/GMW/GMW_deploy/Release/obj/Debug/GMW.dll and b/GMW/GMW_deploy/Release/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW_deploy/Release/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW_deploy/Release/obj/Debug/ResolveAssemblyReference.cache
index 6214e8bd..f6de817f 100644
Binary files a/GMW/GMW_deploy/Release/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW_deploy/Release/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_deploy/Release/obj/Release/GMW.dll b/GMW/GMW_deploy/Release/obj/Release/GMW.dll
index 147d8bd8..e5075e15 100644
Binary files a/GMW/GMW_deploy/Release/obj/Release/GMW.dll and b/GMW/GMW_deploy/Release/obj/Release/GMW.dll differ
diff --git a/GMW/GMW_deploy/Release/obj/Release/ResolveAssemblyReference.cache b/GMW/GMW_deploy/Release/obj/Release/ResolveAssemblyReference.cache
index 7f8e5731..b44c8dc2 100644
Binary files a/GMW/GMW_deploy/Release/obj/Release/ResolveAssemblyReference.cache and b/GMW/GMW_deploy/Release/obj/Release/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_deploy/Release/web.config b/GMW/GMW_deploy/Release/web.config
index 8e07a4d5..3e868cfe 100644
--- a/GMW/GMW_deploy/Release/web.config
+++ b/GMW/GMW_deploy/Release/web.config
@@ -54,6 +54,9 @@
+
+
+
diff --git a/GMW/GMW_deploy/Source/GMW.csproj b/GMW/GMW_deploy/Source/GMW.csproj
index c8f31803..0f50dd20 100644
--- a/GMW/GMW_deploy/Source/GMW.csproj
+++ b/GMW/GMW_deploy/Source/GMW.csproj
@@ -77,10 +77,11 @@
+
-
+
diff --git a/GMW/GMW_deploy/Source/Type/ArtInProd.cs b/GMW/GMW_deploy/Source/Type/ArtInProd.cs
index cac525e9..6b4ceffc 100644
--- a/GMW/GMW_deploy/Source/Type/ArtInProd.cs
+++ b/GMW/GMW_deploy/Source/Type/ArtInProd.cs
@@ -38,14 +38,6 @@ namespace GMW.Type
///
public string CodImpianto { get; set; }
///
- /// Codice Stampo
- ///
- public string CodStampo { get; set; }
- ///
- /// Numero di stampate
- ///
- public decimal NumStampate { get; set; }
- ///
/// Data Inizio produzione
///
public DateTime DataInizio { get; set; }
@@ -54,6 +46,10 @@ namespace GMW.Type
///
public string TurnoInizio { get; set; }
///
+ /// Codice Stampo
+ ///
+ public string CodStampo { get; set; }
+ ///
/// Inizio validità stampo
///
public DateTime InizioValid { get; set; }
@@ -62,6 +58,10 @@ namespace GMW.Type
///
public DateTime? FineValid { get; set; }
///
+ /// Numero di stampate
+ ///
+ public decimal NumStampate { get; set; }
+ ///
/// Numero di figure
///
public decimal NumFigure { get; set; }
diff --git a/GMW/GMW_deploy/Source/WS/bilance.asmx.cs b/GMW/GMW_deploy/Source/WS/bilance.asmx.cs
index 73c48fc4..7675d893 100644
--- a/GMW/GMW_deploy/Source/WS/bilance.asmx.cs
+++ b/GMW/GMW_deploy/Source/WS/bilance.asmx.cs
@@ -13,7 +13,7 @@ namespace GMW.WS
///
/// WebService per gestioen sw bilance
///
- [WebService(Namespace = "http://www.steamware.net/", Description = "Web Services che funziona da collettore di tutte le richieste delle applicazioni per le bilance integrate a GMW v.1.0.15")]
+ [WebService(Namespace = "http://www.steamware.net/", Description = "Web Services che funziona da collettore di tutte le richieste delle applicazioni per le bilance integrate a GMW v.1.0.32")]
[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
[System.ComponentModel.ToolboxItem(false)]
public class bilance : System.Web.Services.WebService
@@ -46,18 +46,26 @@ namespace GMW.WS
gestEl.caricaCompanySito(DataProxy.obj.taAnagCS.GetData());
return gestEl.elencoCompanySito;
}
-#if false
///
- /// fornisce l'anagrafica articoli
+ /// fornisce l'anagrafica clienti
///
- [WebMethod(Description = "Elenco anagrafico articoli")]
- public GMW.Type.Articolo[] ElencoArticoli()
+ [WebMethod(Description = "Elenco anagrafico clienti")]
+ public GMW.Type.Cliente[] ElencoClienti()
{
- gestEl.caricaArticoli(DataProxy.obj.taAnagArt.GetData());
- return gestEl.elencoArticoli;
+ gestEl.caricaClienti(DataProxy.obj.taAnagClienti.GetData());
+ return gestEl.elencoClienti;
+ }
+ ///
+ /// fornisce l'anagrafica operatori
+ ///
+ [WebMethod(Description = "Elenco anagrafico operatori")]
+ public GMW.Type.Operatore[] ElencoOperatori()
+ {
+
+ gestEl.caricaOperatori(DataProxy.obj.taAnagOperatore.GetData());
+ return gestEl.elencoOperatori;
}
-#endif
///
/// Fornisce l'elenco dei tipi di dichiarazione ammessi
///
@@ -108,7 +116,6 @@ namespace GMW.WS
gestEl.caricaBilance(DataProxy.obj.taAnagBil.GetData());
return gestEl.elencoBilance;
}
-#if false
///
/// fornisce l'anagrafica bilance dati codice company e sito
///
@@ -117,22 +124,9 @@ namespace GMW.WS
[WebMethod(Description = "Elenco anagrafico Bilance dati codice company e sito")]
public GMW.Type.Bilancia[] ElencoBilanceByCompanySito(string CodCS)
{
- gestEl.caricaBilance(DataProxy.obj.taAnagBil.getByCompanySito(CodCompany, CodSito));
+ gestEl.caricaBilance(DataProxy.obj.taAnagBil.stp_getByCodCS(CodCS));
return gestEl.elencoBilance;
}
-#endif
-#if false
- ///
- /// fornisce l'elenco di impianti ed articoli attualmente in produzione (per codice anagrafico)
- ///
- [WebMethod(Description = "Elenco impianti ed articoli attualmente in produzione (per codice anagrafico)")]
- public GMW.Type.ArtInProd[] ElencoArtInProd()
- {
- gestEl.caricaArtInProd(DataProxy.obj.taArtInProd.GetData());
- return gestEl.elencoArtInProd;
- }
-
-#endif
#endregion
@@ -295,13 +289,13 @@ namespace GMW.WS
/// codice dell'UDC parent (UDC della tara)
/// peso in kg (0 se non noto) da associare all'UDC come tara del contenitore
/// tipo di dichiarazione (vedere relativa anagrafica consentita, es U=uomo, M=macchina...)
- /// numero pezzi associati all'UDC
+ /// numero pezzi associati all'UDC
/// Peso totale rilevato
/// Peso unitario rilevato
/// Codice dello stato del pezzo (da anagrafica: sabbiato, ...)
/// UDC del nuovo cartellino
[WebMethod(Description = "Fornisce un nuovo codice UDC tipo completo (con pezzi) a partire dalla richiesta e salva i dati")]
- public string UdcCall_GetNew_Pesa(string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int qta, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
+ public string UdcCall_GetNew_Pesa(string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int Quantita, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
{
// ricavo cod company...
string CodCS = "ND";
@@ -315,8 +309,8 @@ namespace GMW.WS
CodCS = memLayer.ML.confReadString("CodCS");
}
int IdxPosizione = 20; // hard coded: è la postazione POST fusione di ambivere!!!
- // faccio update!
- DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_insNewFull(CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_PESA", qta, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_PESA" è "hard coded" nel db... !!!
+ // creo nuovo cartellino!
+ DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_insNewFull(CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_PESA", Quantita, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_PESA" è "hard coded" nel db... !!!
// leggo la riga
try
{
@@ -329,6 +323,72 @@ namespace GMW.WS
return answ;
}
+ ///
+ /// Modifica (se possibile poiché sbloccato) un cartellino esistente dato il suo UDC e salva i dati, restituendo conferma avvenuta modifica (true/false)
+ ///
+ /// codice UDC del cartellino che si vuole modificare
+ /// codice anagrafico della bilanca che effettua la richiesta (codice della pesa)
+ /// codice anagrafico del cliente
+ /// codice del particolare (articolo) - da anagrafica!
+ /// Codice dell'impianto
+ /// Codice dello stampo
+ /// codice dell'esponente dello stampo
+ /// Codice figura
+ /// Data di rif per la dichiarazione
+ /// Turno di rif per la dichiarazione
+ /// codice dell'imballo (tipo cassone) - string LIBERO (non facciamo controlli in input)
+ /// codice dell'operatore
+ /// codice dell'UDC parent (UDC della tara)
+ /// peso in kg (0 se non noto) da associare all'UDC come tara del contenitore
+ /// tipo di dichiarazione (vedere relativa anagrafica consentita, es U=uomo, M=macchina...)
+ /// numero pezzi associati all'UDC
+ /// Peso totale rilevato
+ /// Peso unitario rilevato
+ /// Codice dello stato del pezzo (da anagrafica: sabbiato, ...)
+ /// UDC del nuovo cartellino
+ [WebMethod(Description = "Modifica (se possibile poiché sbloccato) un cartellino esistente dato il suo UDC e salva i dati, restituendo conferma avvenuta modifica (true/false)")]
+ public bool UdcCall_ModificaCartellino(string UDC_edit, string CodBilancia, string CodCliente, string Particolare, string CodImpianto, string CodStampo, string Esponente, string Figura, string UDC_Parent, double Tara, string CodImballo, string CodTipoDichiarazione, string CodSoggetto, int Quantita, float PesoTot, float PesoCad, DateTime DataRif, int TurnoRif, string CodStato)
+ {
+ // ricavo cod company...
+ string CodCS = "ND";
+ bool answ = false;
+ // controllo se si possa aggiornare...
+ GMW.Type.Cartellino currCart = new GMW.Type.Cartellino(DataProxy.obj.taCartellini.stp_getByUdc(UDC_edit)[0]);
+ int maxTimeMod = memLayer.ML.confReadInt("MinutiFinestraEditUDC");
+ double elapsedTime = DateTime.Now.Subtract(currCart.ModDate).TotalMinutes;
+ if (DateTime.Now.Subtract(currCart.ModDate).TotalMinutes > maxTimeMod)
+ {
+ logger.lg.scriviLog(string.Format("NEGATA Richiesta modifica UDC codice {0} fuori tempo massimo: finestra ammessa {1} min, sono passati {2} min da creazione/sblocco", UDC_edit, maxTimeMod, elapsedTime), tipoLog.WARNING);
+ }
+ else
+ {
+ logger.lg.scriviLog(string.Format("Concessa Richiesta modifica UDC codice {0} fuori tempo massimo: finestra ammessa {1} min, sono passati {2} min da creazione/sblocco", UDC_edit, maxTimeMod, elapsedTime), tipoLog.INFO);
+ try
+ {
+ CodCS = DataProxy.obj.taAnagBil.stp_getByCodBilancia(CodBilancia)[0].CodCS;
+ }
+ catch
+ {
+ CodCS = memLayer.ML.confReadString("CodCS");
+ }
+ int IdxPosizione = 20; // hard coded: è la postazione POST fusione di ambivere!!!
+ // faccio update!
+ DS_Applicazione.ElencoCartelliniDataTable tabUdc = DataProxy.obj.taCartellini.stp_updateUDC(UDC_edit, CodCS, CodBilancia, string.Format("{0:yy}", DateTime.Now), CodCliente, Particolare, CodImpianto, CodStampo, Esponente, Figura, DataRif, TurnoRif, CodImballo, CodSoggetto, Tara, IdxPosizione, CodTipoDichiarazione, "UDC_MOD", Quantita, PesoTot, PesoCad, CodStato, UDC_Parent); // ATTENZIONE: "UDC_MOD" è "hard coded" nel db... !!!
+ // leggo la riga
+ try
+ {
+ if (UDC_edit == tabUdc[0].UDC)
+ {
+ answ = true;
+ }
+ }
+ catch
+ { }
+ }
+ return answ;
+ }
+
+
///
/// Annulla un dato UDC (se permesso)
///
diff --git a/GMW/GMW_deploy/Source/Web.config b/GMW/GMW_deploy/Source/Web.config
index 4c8950d7..dc40fc24 100644
--- a/GMW/GMW_deploy/Source/Web.config
+++ b/GMW/GMW_deploy/Source/Web.config
@@ -85,6 +85,7 @@
+
diff --git a/GMW/GMW_deploy/Source/bin/GMW.dll b/GMW/GMW_deploy/Source/bin/GMW.dll
index 147d8bd8..e5075e15 100644
Binary files a/GMW/GMW_deploy/Source/bin/GMW.dll and b/GMW/GMW_deploy/Source/bin/GMW.dll differ
diff --git a/GMW/GMW_deploy/Source/bin/GMW_data.dll b/GMW/GMW_deploy/Source/bin/GMW_data.dll
index c88dbea2..188efcb9 100644
Binary files a/GMW/GMW_deploy/Source/bin/GMW_data.dll and b/GMW/GMW_deploy/Source/bin/GMW_data.dll differ
diff --git a/GMW/GMW_deploy/Source/mazzAppSettings.config b/GMW/GMW_deploy/Source/mazzAppSettings.config
index 62cc312a..c320072d 100644
--- a/GMW/GMW_deploy/Source/mazzAppSettings.config
+++ b/GMW/GMW_deploy/Source/mazzAppSettings.config
@@ -3,5 +3,8 @@
+
+
+
\ No newline at end of file
diff --git a/GMW/GMW_deploy/Source/Type/elenchi.cs b/GMW/GMW_deploy/Source/Type/elenchi.cs
index 9d1f6e43..8bce133e 100644
--- a/GMW/GMW_deploy/Source/Type/elenchi.cs
+++ b/GMW/GMW_deploy/Source/Type/elenchi.cs
@@ -257,7 +257,7 @@ namespace GMW.Type
protected Cartellino[] _elencoCartellini;
///
/// legge una tab di tipo TabStatoOdpUdc e la converte ad un array di tipo UDC[]
///
///
public void caricaCartellini(DS_Applicazione.ElencoCartelliniDataTable tabArt2Imp)
@@ -274,7 +274,7 @@ namespace GMW.Type
}
}
///
- /// Elenco UDC
+ /// Elenco cartellini
///
public Cartellino[] elencoCartellini
{
@@ -286,5 +286,72 @@ namespace GMW.Type
#endregion
+ #region area Clienti
+
+ protected Cliente[] _elencoClienti;
+
+ ///
+ /// legge una tab di tipo anagClienti e la converte ad un array di tipo clienti[]
+ ///
+ ///
+ public void caricaClienti(DS_Applicazione.AnagClientiDataTable tabArt2Imp)
+ {
+ // conto quanti elementi ha la tab x inizializzare l'array...
+ int numRighe = tabArt2Imp.Rows.Count;
+ _elencoClienti = new Cliente[numRighe];
+ // prendo un obj impianto da valorizzare di volta in volta...
+ Cliente obj;
+ for (int i = 0; i < numRighe; i++)
+ {
+ obj = new Cliente(tabArt2Imp[i]);
+ _elencoClienti[i] = obj;
+ }
+ }
+ ///
+ /// Elenco clienti
+ ///
+ public Cliente[] elencoClienti
+ {
+ get
+ {
+ return _elencoClienti;
+ }
+ }
+
+ #endregion
+
+ #region area Operatori
+
+ protected Operatore[] _elencoOperatori;
+
+ ///
+ /// legge una tab di tipo anagOperatori e la converte ad un array di tipo operatori[]
+ ///
+ ///
+ public void caricaOperatori(DS_Applicazione.AnagOperatoriDataTable tabArt2Imp)
+ {
+ // conto quanti elementi ha la tab x inizializzare l'array...
+ int numRighe = tabArt2Imp.Rows.Count;
+ _elencoOperatori = new Operatore[numRighe];
+ // prendo un obj impianto da valorizzare di volta in volta...
+ Operatore obj;
+ for (int i = 0; i < numRighe; i++)
+ {
+ obj = new Operatore(tabArt2Imp[i]);
+ _elencoOperatori[i] = obj;
+ }
+ }
+ ///
+ /// Elenco Operatori
+ ///
+ public Operatore[] elencoOperatori
+ {
+ get
+ {
+ return _elencoOperatori;
+ }
+ }
+
+ #endregion
}
}
@@ -257,7 +257,7 @@ namespace GMW.Type
protected Cartellino[] _elencoCartellini;
///
- /// legge una tab di tipo TabStatoOdpUdc e la converte ad un array di tipo UDC[]
+ /// legge una tab di tipo elencoCartellini e la converte ad un array di tipo cartellini[]
///
///
diff --git a/GMW/GMW_deploy/Source/obj/Debug/GMW.dll b/GMW/GMW_deploy/Source/obj/Debug/GMW.dll
index 0356dddd..326a25de 100644
Binary files a/GMW/GMW_deploy/Source/obj/Debug/GMW.dll and b/GMW/GMW_deploy/Source/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW_deploy/Source/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW_deploy/Source/obj/Debug/ResolveAssemblyReference.cache
index 6214e8bd..f6de817f 100644
Binary files a/GMW/GMW_deploy/Source/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW_deploy/Source/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_deploy/Source/obj/Release/GMW.dll b/GMW/GMW_deploy/Source/obj/Release/GMW.dll
index 147d8bd8..e5075e15 100644
Binary files a/GMW/GMW_deploy/Source/obj/Release/GMW.dll and b/GMW/GMW_deploy/Source/obj/Release/GMW.dll differ
diff --git a/GMW/GMW_deploy/Source/obj/Release/ResolveAssemblyReference.cache b/GMW/GMW_deploy/Source/obj/Release/ResolveAssemblyReference.cache
index 7f8e5731..b44c8dc2 100644
Binary files a/GMW/GMW_deploy/Source/obj/Release/ResolveAssemblyReference.cache and b/GMW/GMW_deploy/Source/obj/Release/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_installer/Release/GMW_installer.msi b/GMW/GMW_installer/Release/GMW_installer.msi
index e1cb344e..907f4315 100644
Binary files a/GMW/GMW_installer/Release/GMW_installer.msi and b/GMW/GMW_installer/Release/GMW_installer.msi differ